﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading;
using System.Threading.Tasks;
using DALWebApi.Interfaces;
using DALWebApi.Repositories;

namespace DALWebApi
{
    public class UOWWebApi : IUOWWebApi, IDisposable
    {
        // Cached list of our already created repos
        protected Dictionary<Type, object> Repositories { get; private set; }
        // list of methods for different repos
        private readonly IDictionary<Type, Func<string, object>> _repositoryFactories;


        private const string AppBaseUrl = "https://localhost:44302/api/";

        public IPersonRepository Persons { get { return GetRepo<IPersonRepository>(AppBaseUrl+"Person/"); } }
        public IContactRepository Contacts { get { return GetRepo<IContactRepository>(AppBaseUrl + "Contact/"); } }
        public IContactTypeRepository ContactTypes { get { return GetRepo<IContactTypeRepository>(AppBaseUrl + "ContactType/"); } }

        public UOWWebApi()
        {

            // get appbaseurl from web.config



            Repositories = new Dictionary<Type, object>();
            _repositoryFactories = GetCustomFactories();
        }
        private T GetRepo<T>(string baseUrl) where T : class
        {
            // Look for T dictionary cache under typeof(T).
            object repoObj;
            Repositories.TryGetValue(typeof(T), out repoObj);
            if (repoObj != null)
            {
                return (T)repoObj;
            }

            Func<string, object> factory;
            _repositoryFactories.TryGetValue(typeof(T), out factory);

            if (factory == null)
            {
                throw new Exception("No factory found!");
            }

            //create repo
            var repo = (T) factory(baseUrl);
            
            //save repo to dictionary
            Repositories[typeof(T)] = repo;

            //return the fucker
            return repo;

        }

        //special repos with custom interfaces are registered here
        private static IDictionary<Type, Func<string, object>> GetCustomFactories()
        {
            return new Dictionary<Type, Func<string, object>>
                {
                    {typeof(IPersonRepository), baseUrl => new PersonRepository(baseUrl)},
                    {typeof(IContactTypeRepository), baseUrl => new ContactTypeRepository(baseUrl)},
                    {typeof(IContactRepository), baseUrl => new ContactRepository(baseUrl)},
                };
        }
        public void Commit()
        {
            // do nothing
        }

        public void Dispose()
        {
        }
    }
}
